searchData={"content_type":"text/markdown","items":[{"doc":"A module to maintain a tree of the structure\n\n```elixir\n%TreeMap{ key: ..., value: ..., children: [%TreeMap{},...]}\n```\n\nand functions to traverse such a tree.\n\n#","ref":"TreeMap.html","title":"TreeMap","type":"module"},{"doc":"```elixir\nroot =\n TreeMap.new(\"1\", \"Root\")\n |> TreeMap.add_child(\"1.1\", \"Sub One\", [TreeMap.new(\"1.1.1\", \"SomeSubSub\")])\n |> TreeMap.add_child(\"1.2\", \"Sub Two\", [TreeMap.new(\"1.2.1\", \"Some other SubSub\")])\n\nexpected = [\"1\", \"1.1\", \"1.1.1\", \"1.2\", \"1.2.1\"]\n\nreceived =\n TreeMap.transduce(root, [], fn a, x -> a ++ [x] end, fn n, acc -> [n | acc] end)\n |> Enum.map(& &1.key)\n\nassert expected == received\n```","ref":"TreeMap.html#module-examples","title":"Examples - TreeMap","type":"module"},{"doc":"Prepend an exisitng child to the children of this node.\n\n#","ref":"TreeMap.html#add_child/2","title":"TreeMap.add_child/2","type":"function"},{"doc":"iex> child = TreeMap.new(\"0\", \"I exist\")\n    iex> TreeMap.new(\"1\", \"Root\") |> TreeMap.add_child(child)\n    %TreeMap{key: \"1\", value: \"Root\", children: [%TreeMap{key: \"0\", value: \"I exist\"}]}","ref":"TreeMap.html#add_child/2-example","title":"Example: - TreeMap.add_child/2","type":"function"},{"doc":"Prepend a new child to the children of this node.\n\n#","ref":"TreeMap.html#add_child/4","title":"TreeMap.add_child/4","type":"function"},{"doc":"iex> TreeMap.new(\"1\", \"Root\") |> TreeMap.add_child(\"1.1\", \"Sub One\")\n    %TreeMap{key: \"1\", value: \"Root\", children: [%TreeMap{key: \"1.1\", value: \"Sub One\"}]}","ref":"TreeMap.html#add_child/4-example","title":"Example: - TreeMap.add_child/4","type":"function"},{"doc":"Return the children of this node.","ref":"TreeMap.html#children/1","title":"TreeMap.children/1","type":"function"},{"doc":"Find a node by it's key or returns `false`","ref":"TreeMap.html#find/2","title":"TreeMap.find/2","type":"function"},{"doc":"#","ref":"TreeMap.html#new/3","title":"TreeMap.new/3","type":"function"},{"doc":"iex> TreeMap.new()\n    %TreeMap{}\n\n    iex> TreeMap.new(123, \"hundretandtwentythree\")\n    %TreeMap{ key: 123, value: \"hundretandtwentythree\"}","ref":"TreeMap.html#new/3-examples","title":"Examples - TreeMap.new/3","type":"function"},{"doc":"Traverse the tree map and apply the given function to each node \n  and a reducer-function to it's children.\n\n#","ref":"TreeMap.html#transduce/4","title":"TreeMap.transduce/4","type":"function"},{"doc":"iex> root = TreeMap.new(\"1\", \"Root\") \n    ...>        |> TreeMap.add_child(\"1.1\", \"Sub One\", [TreeMap.new(\"1.1.1\", \"SomeSubSub\")]) \n    ...>        |> TreeMap.add_child(\"1.2\", \"Sub Two\", [TreeMap.new(\"1.2.1\", \"Some other SubSub\")])\n    ...> TreeMap.transduce(root, 38, fn a, x -> a + Enum.count(x.children) end, fn x, acc -> acc + x end)\n    42\n\n    iex> root = TreeMap.new(\"1\", \"Root\") \n    ...>        |> TreeMap.add_child(\"1.1\", \"Sub One\", [TreeMap.new(\"1.1.1\", \"SomeSubSub\")]) \n    ...>        |> TreeMap.add_child(\"1.2\", \"Sub Two\", [TreeMap.new(\"1.2.1\", \"Some other SubSub\")])\n    ...> TreeMap.transduce(root, [], fn a, x -> a ++ [x.value] end, fn n, acc -> [n | acc] end) \n    [\"Root\", \"Sub One\", \"SomeSubSub\", \"Sub Two\", \"Some other SubSub\"]\n\n    iex> root = TreeMap.new(\"1\", \"Root\") \n    ...>        |> TreeMap.add_child(\"1.1\", \"Sub One\", [TreeMap.new(\"1.1.1\", \"SomeSubSub\")]) \n    ...>        |> TreeMap.add_child(\"1.2\", \"Sub Two\", [TreeMap.new(\"1.2.1\", \"Some other SubSub\")])\n    ...> TreeMap.transduce(root, [], fn a, x -> a ++ [x] end, fn n, acc -> [n | acc] end) \n    ...> |> Enum.map(& &1.key)\n    [\"1\", \"1.1\", \"1.1.1\", \"1.2\", \"1.2.1\"]","ref":"TreeMap.html#transduce/4-example","title":"Example: - TreeMap.transduce/4","type":"function"},{"doc":"Traverse the tree map and apply the given function to each node.\n\n#","ref":"TreeMap.html#traverse/2","title":"TreeMap.traverse/2","type":"function"},{"doc":"iex> root = TreeMap.new(\"1\", \"Root\") |> TreeMap.add_child(\"1.1\", \"Sub One\") |> TreeMap.add_child(\"1.2\", \"Sub Two\")\n    ...> TreeMap.traverse(root, fn x -> x.key end)\n    [\"1\", [\"1.1\", [], \"1.2\", []]]","ref":"TreeMap.html#traverse/2-example","title":"Example: - TreeMap.traverse/2","type":"function"},{"doc":"# README","ref":"readme.html","title":"README","type":"extras"},{"doc":"[![Elixir CI](https://github.com/iboard/tree_map/actions/workflows/elixir.yml/badge.svg)](https://github.com/iboard/tree_map/actions/workflows/elixir.yml)\n\nA module to maintain a tree of the structure\n\n```elixir\n  %TreeMap{ key: ..., value: ..., children: [%TreeMap{},...]}\n```\n\nand functions to traverse such a tree.\n\n#","ref":"readme.html#treemap-0-1","title":"TreeMap 0.1 - README","type":"extras"},{"doc":"```elixir\n root =\n   TreeMap.new(\"1\", \"Root\")\n   |> TreeMap.add_child(\"1.1\", \"Sub One\", [TreeMap.new(\"1.1.1\", \"SomeSubSub\")])\n   |> TreeMap.add_child(\"1.2\", \"Sub Two\", [TreeMap.new(\"1.2.1\", \"Some other SubSub\")])\n\n expected = [\"1\", \"1.1\", \"1.1.1\", \"1.2\", \"1.2.1\"]\n\n received =\n   TreeMap.transduce(root, [], fn a, x -> a ++ [x] end, fn n, acc -> [n | acc] end)\n   |> Enum.map(& &1.key)\n\n assert expected == received\n```","ref":"readme.html#examples","title":"Examples - README","type":"extras"},{"doc":"[Available in Hex](https://hexdocs.pm/tree_map/api-reference.html), the package can be \ninstalled by adding `tree_map` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:tree_map, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation","title":"Installation - README","type":"extras"},{"doc":"# LICENSE\n\n```\n   Copyright 2023 Andreas Altendorfer  \n\n   Licensed under the Apache License, Version 2.0 (the \"License\");\n   you may not use this file except in compliance with the License.\n   You may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\n   Unless required by applicable law or agreed to in writing, software\n   distributed under the License is distributed on an \"AS IS\" BASIS,\n   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n   See the License for the specific language governing permissions and\n   limitations under the License.\n\n```","ref":"license.html","title":"LICENSE","type":"extras"},{"doc":"# Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"","ref":"changelog.html#2023-09-15-initial-version-0-1-0","title":"2023-09-15 Initial version 0.1.0 - Changelog","type":"extras"}]}